@@ -3,7 +3,7 @@
  * 
  * (C) 2000 Daniel Kobras <kobras@linux.de>
  * 
- * $Id: state.h,v 1.2 2000/10/01 17:28:42 belbo Exp $
+ * $Id: state.h,v 1.4 2004/04/08 20:13:44 nold Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,6 +40,9 @@ typedef enum disk_states {
 	DISK_STATE_STOPPED
 } disk_state_t;
 
+void devname_init(void);
+char *devname_get(char *);
+
 void nfd_daemon(disk_info_t head, disk_stat_t stat);
 
 #endif
